
NEWS
====

Londiste v3.5
-------------

* obfuscate: Improved decoding/encoding handling
* Setup Github Actions
* Code cleanups
* Drop Debian packaging

Londiste v3.4.1
---------------

* obfuscate: improvements for better usage with inheritance
* pip: due to psycopg2/psycopg2-binary duality, drop direct dependency

Londiste v3.4
-------------

* Move to separate repo

